@@ -11,18 +11,18 @@ _ENV_VAR = "FERNET_KEY"
 
 def encrypt(text: str, /, *, env_var: str = _ENV_VAR) -> bytes:
     """Encrypt a string."""
-    return get_fernet(env_var=env_var).encrypt(text.encode())
+    return get_fernet(env_var).encrypt(text.encode())
 
 
 def decrypt(text: bytes, /, *, env_var: str = _ENV_VAR) -> str:
     """Encrypt a string."""
-    return get_fernet(env_var=env_var).decrypt(text).decode()
+    return get_fernet(env_var).decrypt(text).decode()
 
 
 ##
 
 
-def get_fernet(*, env_var: str = _ENV_VAR) -> Fernet:
+def get_fernet(env_var: str = _ENV_VAR, /) -> Fernet:
     """Get the Fernet key."""
     if (key := getenv(env_var)) is None:
         raise GetFernetError(env_var=env_var)
