@@ -564,7 +564,7 @@ def _object_hook(
                 )
                 for k, v in mapping.items()
             }
-        case _ as never:
+        case never:
             assert_never(never)
 
 
@@ -1006,7 +1006,7 @@ class GetLogRecordsOutput:
                         for r in records
                         if (r.func_name is not None) and search(func_name, r.func_name)
                     ]
-                case _ as never:
+                case never:
                     assert_never(never)
         if extra is not None:
             match extra:
@@ -1019,7 +1019,7 @@ class GetLogRecordsOutput:
                         if (r.extra is not None)
                         and set(r.extra).issuperset(always_iterable(keys))
                     ]
-                case _ as never:
+                case never:
                     assert_never(never)
         if log_file is not None:
             match log_file:
@@ -1034,7 +1034,7 @@ class GetLogRecordsOutput:
                         if (r.log_file is not None)
                         and search(str(log_file), str(r.log_file))
                     ]
-                case _ as never:
+                case never:
                     assert_never(never)
         if log_file_line_num is not None:
             match log_file_line_num:
@@ -1048,7 +1048,7 @@ class GetLogRecordsOutput:
                     records = [
                         r for r in records if r.log_file_line_num == log_file_line_num
                     ]
-                case _ as never:
+                case never:
                     assert_never(never)
         if min_log_file_line_num is not None:
             records = [
