@@ -7,7 +7,7 @@ from collections.abc import Set as AbstractSet
 from contextlib import suppress
 from dataclasses import asdict, dataclass
 from functools import partial, reduce
-from itertools import chain, product
+from itertools import chain, pairwise, product
 from math import ceil, log
 from pathlib import Path
 from typing import TYPE_CHECKING, Any, Literal, assert_never, cast, overload, override
@@ -33,6 +33,7 @@ from polars import (
     any_horizontal,
     col,
     concat,
+    datetime_range,
     int_range,
     lit,
     struct,
@@ -49,6 +50,7 @@ from polars.exceptions import (
 )
 from polars.schema import Schema
 from polars.testing import assert_frame_equal, assert_series_equal
+from whenever import ZonedDateTime
 
 from utilities.dataclasses import _YieldFieldsInstance, yield_fields
 from utilities.errors import ImpossibleCaseError
@@ -122,6 +124,7 @@ if TYPE_CHECKING:
 
 
 type ExprLike = MaybeStr[Expr]
+type ExprOrSeries = Expr | Series
 DatetimeHongKong = Datetime(time_zone="Asia/Hong_Kong")
 DatetimeTokyo = Datetime(time_zone="Asia/Tokyo")
 DatetimeUSCentral = Datetime(time_zone="US/Central")
@@ -129,6 +132,7 @@ DatetimeUSEastern = Datetime(time_zone="US/Eastern")
 DatetimeUTC = Datetime(time_zone="UTC")
 _FINITE_EWM_MIN_WEIGHT = 0.9999
 
+
 ##
 
 
@@ -208,7 +212,7 @@ def acf(
             df_confints = _acf_process_confints(confints)
             df_qstats_pvalues = _acf_process_qstats_pvalues(qstats, pvalues)
             return join(df_acfs, df_confints, df_qstats_pvalues, on=["lag"], how="left")
-        case _ as never:
+        case never:
             assert_never(never)
 
 
@@ -238,11 +242,6 @@ def _acf_process_qstats_pvalues(qstats: NDArrayF, pvalues: NDArrayF, /) -> DataF
 ##
 
 
-# def acf_halflife(series: Series,/)
-
-##
-
-
 def adjust_frequencies(
     series: Series,
     /,
@@ -264,6 +263,37 @@ def adjust_frequencies(
 ##
 
 
+def all_dataframe_columns(
+    df: DataFrame, expr: IntoExprColumn, /, *exprs: IntoExprColumn
+) -> Series:
+    """Return a DataFrame column with `AND` applied to additional exprs/series."""
+    name = get_expr_name(df, expr)
+    return df.select(all_horizontal(expr, *exprs).alias(name))[name]
+
+
+def any_dataframe_columns(
+    df: DataFrame, expr: IntoExprColumn, /, *exprs: IntoExprColumn
+) -> Series:
+    """Return a DataFrame column with `OR` applied to additional exprs/series."""
+    name = get_expr_name(df, expr)
+    return df.select(any_horizontal(expr, *exprs).alias(name))[name]
+
+
+def all_series(series: Series, /, *columns: ExprOrSeries) -> Series:
+    """Return a Series with `AND` applied to additional exprs/series."""
+    return all_dataframe_columns(series.to_frame(), series.name, *columns)
+
+
+def any_series(series: Series, /, *columns: ExprOrSeries) -> Series:
+    """Return a Series with `OR` applied to additional exprs/series."""
+    df = series.to_frame()
+    name = series.name
+    return df.select(any_horizontal(name, *columns).alias(name))[name]
+
+
+##
+
+
 def append_dataclass(df: DataFrame, obj: Dataclass, /) -> DataFrame:
     """Append a dataclass object to a DataFrame."""
     non_null_fields = {k: v for k, v in asdict(obj).items() if v is not None}
@@ -345,7 +375,7 @@ def bernoulli(
             return bernoulli(series.len(), true=true, seed=seed, name=name)
         case DataFrame() as df:
             return bernoulli(df.height, true=true, seed=seed, name=name)
-        case _ as never:
+        case never:
             assert_never(never)
 
 
@@ -379,7 +409,7 @@ def boolean_value_counts(
                 (false / total).alias("false (%)"),
                 (null / total).alias("null (%)"),
             )
-        case _ as never:
+        case never:
             assert_never(never)
 
 
@@ -427,8 +457,8 @@ def ceil_datetime(column: ExprLike, every: ExprLike, /) -> Expr: ...
 @overload
 def ceil_datetime(column: Series, every: ExprLike, /) -> Series: ...
 @overload
-def ceil_datetime(column: IntoExprColumn, every: ExprLike, /) -> Expr | Series: ...
-def ceil_datetime(column: IntoExprColumn, every: ExprLike, /) -> Expr | Series:
+def ceil_datetime(column: IntoExprColumn, every: ExprLike, /) -> ExprOrSeries: ...
+def ceil_datetime(column: IntoExprColumn, every: ExprLike, /) -> ExprOrSeries:
     """Compute the `ceil` of a datetime column."""
     column = ensure_expr_or_series(column)
     rounded = column.dt.round(every)
@@ -763,7 +793,7 @@ def choice(
                 name=name,
                 dtype=dtype,
             )
-        case _ as never:
+        case never:
             assert_never(never)
 
 
@@ -849,13 +879,13 @@ def cross(
     up_or_down: Literal["up", "down"],
     other: Number | IntoExprColumn,
     /,
-) -> Expr | Series: ...
+) -> ExprOrSeries: ...
 def cross(
     expr: IntoExprColumn,
     up_or_down: Literal["up", "down"],
     other: Number | IntoExprColumn,
     /,
-) -> Expr | Series:
+) -> ExprOrSeries:
     """Compute when a cross occurs."""
     return _cross_or_touch(expr, "cross", up_or_down, other)
 
@@ -874,13 +904,13 @@ def touch(
     up_or_down: Literal["up", "down"],
     other: Number | IntoExprColumn,
     /,
-) -> Expr | Series: ...
+) -> ExprOrSeries: ...
 def touch(
     expr: IntoExprColumn,
     up_or_down: Literal["up", "down"],
     other: Number | IntoExprColumn,
     /,
-) -> Expr | Series:
+) -> ExprOrSeries:
     """Compute when a touch occurs."""
     return _cross_or_touch(expr, "touch", up_or_down, other)
 
@@ -891,7 +921,7 @@ def _cross_or_touch(
     up_or_down: Literal["up", "down"],
     other: Number | IntoExprColumn,
     /,
-) -> Expr | Series:
+) -> ExprOrSeries:
     """Compute when a column crosses/touches a threshold."""
     expr = ensure_expr_or_series(expr)
     match other:
@@ -899,7 +929,7 @@ def _cross_or_touch(
             ...
         case str() | Expr() | Series():
             other = ensure_expr_or_series(other)
-        case _ as never:
+        case never:
             assert_never(never)
     enough = int_range(end=pl.len()) >= 1
     match cross_or_touch, up_or_down:
@@ -911,7 +941,7 @@ def _cross_or_touch(
             current = expr >= other
         case "touch", "down":
             current = expr <= other
-        case _ as never:
+        case never:
             assert_never(never)
     prev = current.shift()
     result = when(enough & expr.is_finite()).then(current & ~prev)
@@ -963,7 +993,7 @@ def cross_rolling_quantile(
     weights: list[float] | None = None,
     min_samples: int | None = None,
     center: bool = False,
-) -> Expr | Series: ...
+) -> ExprOrSeries: ...
 def cross_rolling_quantile(
     expr: IntoExprColumn,
     up_or_down: Literal["up", "down"],
@@ -975,7 +1005,7 @@ def cross_rolling_quantile(
     weights: list[float] | None = None,
     min_samples: int | None = None,
     center: bool = False,
-) -> Expr | Series:
+) -> ExprOrSeries:
     """Compute when a column crosses its rolling quantile."""
     expr = ensure_expr_or_series(expr)
     rolling = expr.rolling_quantile(
@@ -1180,8 +1210,8 @@ def ensure_expr_or_series(column: ExprLike, /) -> Expr: ...
 @overload
 def ensure_expr_or_series(column: Series, /) -> Series: ...
 @overload
-def ensure_expr_or_series(column: IntoExprColumn, /) -> Expr | Series: ...
-def ensure_expr_or_series(column: IntoExprColumn, /) -> Expr | Series:
+def ensure_expr_or_series(column: IntoExprColumn, /) -> ExprOrSeries: ...
+def ensure_expr_or_series(column: IntoExprColumn, /) -> ExprOrSeries:
     """Ensure a column expression or Series is returned."""
     return col(column) if isinstance(column, str) else column
 
@@ -1191,7 +1221,7 @@ def ensure_expr_or_series(column: IntoExprColumn, /) -> Expr | Series:
 
 def ensure_expr_or_series_many(
     *columns: IntoExprColumn, **named_columns: IntoExprColumn
-) -> Sequence[Expr | Series]:
+) -> Sequence[ExprOrSeries]:
     """Ensure a set of column expressions and/or Series are returned."""
     args = map(ensure_expr_or_series, columns)
     kwargs = (ensure_expr_or_series(v).alias(k) for k, v in named_columns.items())
@@ -1233,7 +1263,7 @@ def finite_ewm_mean(
     half_life: float | None = None,
     alpha: float | None = None,
     min_weight: float = _FINITE_EWM_MIN_WEIGHT,
-) -> Expr | Series: ...
+) -> ExprOrSeries: ...
 def finite_ewm_mean(
     column: IntoExprColumn,
     /,
@@ -1243,7 +1273,7 @@ def finite_ewm_mean(
     half_life: float | None = None,
     alpha: float | None = None,
     min_weight: float = _FINITE_EWM_MIN_WEIGHT,
-) -> Expr | Series:
+) -> ExprOrSeries:
     """Compute a finite EWMA."""
     try:
         weights = _finite_ewm_weights(
@@ -1309,8 +1339,8 @@ def floor_datetime(column: ExprLike, every: ExprLike, /) -> Expr: ...
 @overload
 def floor_datetime(column: Series, every: ExprLike, /) -> Series: ...
 @overload
-def floor_datetime(column: IntoExprColumn, every: ExprLike, /) -> Expr | Series: ...
-def floor_datetime(column: IntoExprColumn, every: ExprLike, /) -> Expr | Series:
+def floor_datetime(column: IntoExprColumn, every: ExprLike, /) -> ExprOrSeries: ...
+def floor_datetime(column: IntoExprColumn, every: ExprLike, /) -> ExprOrSeries:
     """Compute the `floor` of a datetime column."""
     column = ensure_expr_or_series(column)
     rounded = column.dt.round(every)
@@ -1338,13 +1368,24 @@ def get_data_type_or_series_time_zone(
             dtype = dtype_cls()
         case Series() as series:
             dtype = series.dtype
-        case _ as never:
+        case never:
             assert_never(never)
-    if not isinstance(dtype, Datetime):
-        raise _GetDataTypeOrSeriesTimeZoneNotDateTimeError(dtype=dtype)
-    if dtype.time_zone is None:
-        raise _GetDataTypeOrSeriesTimeZoneNotZonedError(dtype=dtype)
-    return ZoneInfo(dtype.time_zone)
+    match dtype:
+        case Datetime() as datetime:
+            if datetime.time_zone is None:
+                raise _GetDataTypeOrSeriesTimeZoneNotZonedError(dtype=datetime)
+            return ZoneInfo(datetime.time_zone)
+        case Struct() as struct:
+            try:
+                return one({
+                    get_data_type_or_series_time_zone(f.dtype) for f in struct.fields
+                })
+            except OneNonUniqueError as error:
+                raise _GetDataTypeOrSeriesTimeZoneStructNonUniqueError(
+                    dtype=struct, first=error.first, second=error.second
+                ) from None
+        case _:
+            raise _GetDataTypeOrSeriesTimeZoneNotDateTimeError(dtype=dtype)
 
 
 @dataclass(kw_only=True, slots=True)
@@ -1366,6 +1407,18 @@ class _GetDataTypeOrSeriesTimeZoneNotZonedError(GetDataTypeOrSeriesTimeZoneError
         return f"Data type must be zoned; got {self.dtype}"
 
 
+@dataclass(kw_only=True, slots=True)
+class _GetDataTypeOrSeriesTimeZoneStructNonUniqueError(
+    GetDataTypeOrSeriesTimeZoneError
+):
+    first: ZoneInfo
+    second: ZoneInfo
+
+    @override
+    def __str__(self) -> str:
+        return f"Struct data type must contain exactly one time zone; got {self.first}, {self.second} and perhaps more"
+
+
 ##
 
 
@@ -1377,7 +1430,7 @@ def get_expr_name(obj: Series | DataFrame, expr: IntoExprColumn, /) -> str:
         case DataFrame() as df:
             selected = df.select(expr)
             return one(selected.columns)
-        case _ as never:
+        case never:
             assert_never(never)
 
 
@@ -1448,6 +1501,37 @@ class _GetSeriesNumberOfDecimalsAllNullError(GetSeriesNumberOfDecimalsError):
 ##
 
 
+@overload
+def increasing_horizontal(*columns: ExprLike) -> Expr: ...
+@overload
+def increasing_horizontal(*columns: Series) -> Series: ...
+@overload
+def increasing_horizontal(*columns: IntoExprColumn) -> ExprOrSeries: ...
+def increasing_horizontal(*columns: IntoExprColumn) -> ExprOrSeries:
+    """Check if a set of columns are increasing."""
+    columns2 = ensure_expr_or_series_many(*columns)
+    if len(columns2) == 0:
+        return lit(value=True, dtype=Boolean)
+    return all_horizontal(prev < curr for prev, curr in pairwise(columns2))
+
+
+@overload
+def decreasing_horizontal(*columns: ExprLike) -> Expr: ...
+@overload
+def decreasing_horizontal(*columns: Series) -> Series: ...
+@overload
+def decreasing_horizontal(*columns: IntoExprColumn) -> ExprOrSeries: ...
+def decreasing_horizontal(*columns: IntoExprColumn) -> ExprOrSeries:
+    """Check if a set of columns are decreasing."""
+    columns2 = ensure_expr_or_series_many(*columns)
+    if len(columns2) == 0:
+        return lit(value=True, dtype=Boolean)
+    return all_horizontal(prev > curr for prev, curr in pairwise(columns2))
+
+
+##
+
+
 def insert_after(df: DataFrame, column: str, value: IntoExprColumn, /) -> DataFrame:
     """Insert a series after an existing column; not in-place."""
     columns = df.columns
@@ -1575,7 +1659,7 @@ def integers(
                 name=name,
                 dtype=dtype,
             )
-        case _ as never:
+        case never:
             assert_never(never)
 
 
@@ -1596,13 +1680,13 @@ def is_near_event(
     before: int = 0,
     after: int = 0,
     **named_exprs: IntoExprColumn,
-) -> Expr | Series: ...
+) -> ExprOrSeries: ...
 def is_near_event(
     *exprs: IntoExprColumn,
     before: int = 0,
     after: int = 0,
     **named_exprs: IntoExprColumn,
-) -> Expr | Series:
+) -> ExprOrSeries:
     """Compute the rows near any event."""
     if before <= -1:
         raise _IsNearEventBeforeError(before=before)
@@ -1880,7 +1964,7 @@ def map_over_columns(
             return _map_over_series_one(func, series)
         case DataFrame() as df:
             return df.select(*(_map_over_series_one(func, df[c]) for c in df.columns))
-        case _ as never:
+        case never:
             assert_never(never)
 
 
@@ -1960,13 +2044,26 @@ def normal(
             return normal(
                 df.height, loc=loc, scale=scale, seed=seed, name=name, dtype=dtype
             )
-        case _ as never:
+        case never:
             assert_never(never)
 
 
 ##
 
 
+def offset_datetime(
+    datetime: ZonedDateTime, offset: str, /, *, n: int = 1
+) -> ZonedDateTime:
+    """Offset a datetime as `polars` would."""
+    sr = Series(values=[datetime.py_datetime()])
+    for _ in range(n):
+        sr = sr.dt.offset_by(offset)
+    return ZonedDateTime.from_py_datetime(sr.item())
+
+
+##
+
+
 @overload
 def order_of_magnitude(column: ExprLike, /, *, round_: bool = False) -> Expr: ...
 @overload
@@ -1974,10 +2071,10 @@ def order_of_magnitude(column: Series, /, *, round_: bool = False) -> Series: ..
 @overload
 def order_of_magnitude(
     column: IntoExprColumn, /, *, round_: bool = False
-) -> Expr | Series: ...
+) -> ExprOrSeries: ...
 def order_of_magnitude(
     column: IntoExprColumn, /, *, round_: bool = False
-) -> Expr | Series:
+) -> ExprOrSeries:
     """Compute the order of magnitude of a column."""
     column = ensure_expr_or_series(column)
     result = column.abs().log10()
@@ -1987,6 +2084,75 @@ def order_of_magnitude(
 ##
 
 
+@overload
+def period_range(
+    start: ZonedDateTime,
+    end_or_length: ZonedDateTime | int,
+    /,
+    *,
+    interval: str = "1d",
+    time_unit: TimeUnit | None = None,
+    time_zone: TimeZoneLike | None = None,
+    eager: Literal[True],
+) -> Series: ...
+@overload
+def period_range(
+    start: ZonedDateTime,
+    end_or_length: ZonedDateTime | int,
+    /,
+    *,
+    interval: str = "1d",
+    time_unit: TimeUnit | None = None,
+    time_zone: TimeZoneLike | None = None,
+    eager: Literal[False] = False,
+) -> Expr: ...
+@overload
+def period_range(
+    start: ZonedDateTime,
+    end_or_length: ZonedDateTime | int,
+    /,
+    *,
+    interval: str = "1d",
+    time_unit: TimeUnit | None = None,
+    time_zone: TimeZoneLike | None = None,
+    eager: bool = False,
+) -> Series | Expr: ...
+def period_range(
+    start: ZonedDateTime,
+    end_or_length: ZonedDateTime | int,
+    /,
+    *,
+    interval: str = "1d",
+    time_unit: TimeUnit | None = None,
+    time_zone: TimeZoneLike | None = None,
+    eager: bool = False,
+) -> Series | Expr:
+    """Construct a period range."""
+    time_zone_use = None if time_zone is None else ensure_time_zone(time_zone).key
+    match end_or_length:
+        case ZonedDateTime() as end:
+            ...
+        case int() as length:
+            end = offset_datetime(start, interval, n=length)
+        case never:
+            assert_never(never)
+    starts = datetime_range(
+        start.py_datetime(),
+        end.py_datetime(),
+        interval,
+        closed="left",
+        time_unit=time_unit,
+        time_zone=time_zone_use,
+        eager=eager,
+    ).alias("start")
+    ends = (starts.dt.offset_by(interval)).alias("end")
+    period = struct(starts, ends)
+    return try_reify_expr(period, starts, ends)
+
+
+##
+
+
 def reify_exprs(
     *exprs: IntoExprColumn, **named_exprs: IntoExprColumn
 ) -> Expr | Series | DataFrame:
@@ -2192,7 +2358,7 @@ def _reconstruct_dtype(obj: _DeconDType, /) -> PolarsDataType:
             return List(_reconstruct_dtype(inner))
         case "Struct", inner:
             return Struct(_reconstruct_schema(inner))
-        case _ as never:
+        case never:
             assert_never(never)
 
 
@@ -2309,7 +2475,7 @@ class _StructFromDataClassTypeError(StructFromDataClassError):
 
 def try_reify_expr(
     expr: IntoExprColumn, /, *exprs: IntoExprColumn, **named_exprs: IntoExprColumn
-) -> Expr | Series:
+) -> ExprOrSeries:
     """Try reify an expression."""
     expr = ensure_expr_or_series(expr)
     all_exprs = ensure_expr_or_series_many(*exprs, **named_exprs)
@@ -2322,7 +2488,7 @@ def try_reify_expr(
             return series
         case DataFrame() as df:
             return df[get_expr_name(df, expr)]
-        case _ as never:
+        case never:
             assert_never(never)
 
 
@@ -2355,7 +2521,7 @@ def uniform(
             return uniform(
                 df.height, low=low, high=high, seed=seed, name=name, dtype=dtype
             )
-        case _ as never:
+        case never:
             assert_never(never)
 
 
@@ -2376,8 +2542,8 @@ def week_num(column: ExprLike, /, *, start: WeekDay = "mon") -> Expr: ...
 @overload
 def week_num(column: Series, /, *, start: WeekDay = "mon") -> Series: ...
 @overload
-def week_num(column: IntoExprColumn, /, *, start: WeekDay = "mon") -> Expr | Series: ...
-def week_num(column: IntoExprColumn, /, *, start: WeekDay = "mon") -> Expr | Series:
+def week_num(column: IntoExprColumn, /, *, start: WeekDay = "mon") -> ExprOrSeries: ...
+def week_num(column: IntoExprColumn, /, *, start: WeekDay = "mon") -> ExprOrSeries:
     """Compute the week number of a date column."""
     column = ensure_expr_or_series(column)
     epoch = column.dt.epoch(time_unit="d").alias("epoch")
@@ -2423,6 +2589,7 @@ __all__ = [
     "DatetimeUSEastern",
     "DatetimeUTC",
     "DropNullStructSeriesError",
+    "ExprOrSeries",
     "FiniteEWMMeanError",
     "GetDataTypeOrSeriesTimeZoneError",
     "GetSeriesNumberOfDecimalsError",
@@ -2435,6 +2602,10 @@ __all__ = [
     "StructFromDataClassError",
     "acf",
     "adjust_frequencies",
+    "all_dataframe_columns",
+    "all_series",
+    "any_dataframe_columns",
+    "any_series",
     "append_dataclass",
     "are_frames_equal",
     "bernoulli",
@@ -2449,6 +2620,7 @@ __all__ = [
     "cross",
     "dataclass_to_dataframe",
     "dataclass_to_schema",
+    "decreasing_horizontal",
     "deserialize_dataframe",
     "drop_null_struct_series",
     "ensure_data_type",
@@ -2460,6 +2632,7 @@ __all__ = [
     "get_expr_name",
     "get_frequency_spectrum",
     "get_series_number_of_decimals",
+    "increasing_horizontal",
     "insert_after",
     "insert_before",
     "insert_between",
@@ -2473,7 +2646,9 @@ __all__ = [
     "nan_sum_agg",
     "nan_sum_cols",
     "normal",
+    "offset_datetime",
     "order_of_magnitude",
+    "period_range",
     "read_dataframe",
     "read_series",
     "replace_time_zone",
